@@ -1,4 +1,9 @@
-from .errors import InterpreterError
+'''
+These are some utilites used when writing and handling interpreters.
+'''
+
+from cytoplasm import configuration
+from cytoplasm.errors import InterpreterError
 
 def SaveReturned(fn):
     '''Some potential interpreters, like Mako, don't give you an easy way to save to a destination.
@@ -17,7 +22,7 @@ def SaveReturned(fn):
 
 def interpret(file, destination, **kwargs):
     "Interpret a file with an interpreter according to its suffix."
-    from .configuration import interpreters
+    interpreters = configuration.get_config().interpreters
     for ending in interpreters.keys():
         # if the file has a suffix that matches any of the interpreters,
         # parse that file with that interpreter
